import os

# have to discuss about the default location
DEFAULT_GEMPYP_FOLDER = os.getcwd()
DEBUG = True
THREADS = 8
_VERSION = "1.0.0"

urls = {

    "suiteInfo": "https://apis.gemecosystem.com/suiteinfo/",
    "suiteExec": "https://apis.gemecosystem.com/suiteexe",
    "testcases": "https://apis.gemecosystem.com/testcase",

}
count = 0
